@@ -205,6 +205,26 @@ void ProcessDataModel::setEnabledAttributes(const QStringList &enabledAttributes
     emit enabledAttributesChanged();
 }
 
+bool ProcessDataModel::enabled() const
+{
+    return d->m_timer->isActive();
+}
+
+void ProcessDataModel::setEnabled(bool newEnabled)
+{
+    if (newEnabled == d->m_timer->isActive()) {
+        return;
+    }
+
+    if (newEnabled) {
+        d->m_timer->start();
+    } else {
+        d->m_timer->stop();
+    }
+
+    Q_EMIT enabledChanged();
+}
+
 QModelIndex ProcessDataModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (row < 0) {
@@ -264,7 +284,7 @@ ProcessAttributeModel *ProcessDataModel::attributesModel()
 {
     // lazy load
     if (!d->m_attributeModel) {
-        d->m_attributeModel = new KSysGuard::ProcessAttributeModel(d->m_processes, this);
+        d->m_attributeModel = new KSysGuard::ProcessAttributeModel(d->m_availableAttributes.values().toVector(), this);
     }
     return d->m_attributeModel;
 }
@@ -333,5 +353,3 @@ QVariant ProcessDataModel::headerData(int section, Qt::Orientation orientation,
 
     return QVariant();
 }
-
-#include "process_data_model.moc"
