@@ -29,7 +29,8 @@ class SensorDaemonInterface::Private
 {
 public:
     std::unique_ptr<org::kde::KSysGuardDaemon> dbusInterface;
-
+    std::unique_ptr<QDBusServiceWatcher> serviceWatcher;
+    QStringList subscribedSensors;
     static const QString SensorServiceName;
     static const QString SensorPath;
 };
@@ -46,12 +47,19 @@ SensorDaemonInterface::SensorDaemonInterface(QObject *parent)
     qDBusRegisterMetaType<SensorDataList>();
     qDBusRegisterMetaType<SensorInfoMap>();
 
-    d->dbusInterface = std::make_unique<org::kde::KSysGuardDaemon>(Private::SensorServiceName, Private::SensorPath, QDBusConnection::sessionBus());
+    d->serviceWatcher = std::make_unique<QDBusServiceWatcher>(d->SensorServiceName, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration);
+    connect(d->serviceWatcher.get(), &QDBusServiceWatcher::serviceUnregistered, this, &SensorDaemonInterface::reconnect);
+    reconnect();
+}
 
+void KSysGuard::SensorDaemonInterface::reconnect()
+{
+    d->dbusInterface = std::make_unique<org::kde::KSysGuardDaemon>(Private::SensorServiceName, Private::SensorPath, QDBusConnection::sessionBus());
     connect(d->dbusInterface.get(), &org::kde::KSysGuardDaemon::sensorMetaDataChanged, this, &SensorDaemonInterface::onMetaDataChanged);
     connect(d->dbusInterface.get(), &org::kde::KSysGuardDaemon::newSensorData, this, &SensorDaemonInterface::onValueChanged);
     connect(d->dbusInterface.get(), &org::kde::KSysGuardDaemon::sensorAdded, this, &SensorDaemonInterface::sensorAdded);
     connect(d->dbusInterface.get(), &org::kde::KSysGuardDaemon::sensorRemoved, this, &SensorDaemonInterface::sensorRemoved);
+    subscribe(d->subscribedSensors);
 }
 
 SensorDaemonInterface::~SensorDaemonInterface()
@@ -112,6 +120,7 @@ void SensorDaemonInterface::subscribe(const QString &sensorId)
 void KSysGuard::SensorDaemonInterface::subscribe(const QStringList &sensorIds)
 {
     d->dbusInterface->subscribe(sensorIds);
+    d->subscribedSensors.append(sensorIds);
 }
 
 void SensorDaemonInterface::unsubscribe(const QString &sensorId)
