@@ -24,6 +24,7 @@
 #include <QDebug>
 #include <QMetaEnum>
 #include <QMimeData>
+#include <QRegularExpression>
 
 #include "formatter/Formatter.h"
 
@@ -31,6 +32,7 @@
 #include "SensorDaemonInterface_p.h"
 #include "SensorInfo_p.h"
 #include "SensorQuery.h"
+#include "SensorGroup_p.h"
 
 using namespace KSysGuard;
 
@@ -76,10 +78,12 @@ public:
         : rootItem(new SensorTreeItem)
         , q(qq)
     {
+        m_sensorGroup = new SensorGroup;
     }
     ~Private()
     {
         delete rootItem;
+        delete m_sensorGroup;
     }
 
     SensorTreeItem *rootItem;
@@ -92,6 +96,10 @@ public:
 
     SensorTreeItem *find(const QString &sensorId);
 
+    SensorGroup *m_sensorGroup;
+
+    QHash<QString, int> m_groupMatches;
+
 private:
     SensorTreeModel *q;
 };
@@ -105,6 +113,27 @@ void SensorTreeModel::Private::addSensor(const QString &sensorId, const SensorIn
         return;
     }
 
+    QString sensorIdExpr = m_sensorGroup->groupRegexForId(sensorId);
+
+    if (!sensorIdExpr.isEmpty()) {
+        if (m_groupMatches.contains(sensorIdExpr)) {
+            m_groupMatches[sensorIdExpr]++;
+        } else {
+            m_groupMatches[sensorIdExpr] = 1;
+        }
+        
+        if (m_groupMatches[sensorIdExpr] == 2) {
+            SensorInfo newInfo;
+            newInfo.name = m_sensorGroup->sensorNameForRegEx(sensorIdExpr);
+            newInfo.description = info.description;
+            newInfo.variantType = info.variantType;
+            newInfo.unit = info.unit;
+            newInfo.min = info.min;
+            newInfo.max = info.max;
+            
+            addSensor(sensorIdExpr, newInfo);
+        }
+    }
     SensorTreeItem *item = rootItem;
 
     for (auto segment : segments) {
@@ -112,6 +141,7 @@ void SensorTreeModel::Private::addSensor(const QString &sensorId, const SensorIn
 
         if (child) {
             item = child;
+
         } else {
             SensorTreeItem *newItem = new SensorTreeItem();
             newItem->parent = item;
@@ -134,6 +164,16 @@ void SensorTreeModel::Private::addSensor(const QString &sensorId, const SensorIn
 
 void SensorTreeModel::Private::removeSensor(const QString &sensorId)
 {
+    QString sensorIdExpr = m_sensorGroup->groupRegexForId(sensorId);
+    if (!sensorIdExpr.isEmpty()) {
+        if (m_groupMatches[sensorIdExpr] == 1) {
+            m_groupMatches.remove(sensorIdExpr);
+            removeSensor(sensorIdExpr);
+        } else if (m_groupMatches.contains(sensorIdExpr)) {
+            m_groupMatches[sensorIdExpr]--;
+        }
+    }
+
     SensorTreeItem *item = find(sensorId);
     if (!item) {
         return;
@@ -263,7 +303,7 @@ QVariant SensorTreeModel::data(const QModelIndex &index, int role) const
             return info.name;
         }
 
-        return item->segment;
+        return d->m_sensorGroup->segmentNameForRegEx(item->segment);
     // Only leaf nodes are valid sensors
     } else if (role == SensorId) {
         if (rowCount(index)) {
